"""Validation framework for model verification against reference data."""

from cvd_risk_calculator.validation.validation import ValidationFramework, ValidationResult

__all__ = ["ValidationFramework", "ValidationResult"]

